import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import cx from 'classnames'
import Pane from './Pane'
import theme from './theme'
import SuccessAlertIcon from './SuccessAlertIcon'
import QuestionAlertIcon from './QuestionAlertIcon'
import DangerAlertIcon from './DangerAlertIcon'
import WarningAlertIcon from './WarningAlertIcon'
const { minorScale, majorScale } = theme

const getStyle = ({ type, showTrim }) => {
  const trim = showTrim ? {
    '&:before': {
      content: '""',
      width: minorScale(1),
      height: '100%',
      position: 'absolute',
      top: 0,
      left: 0,
      backgroundColor: theme.colors[type]
    }
  } : {}

  return css({
    'boxShadow': `${theme.shadows[0]}, inset 0 0 0 1px ${theme.colors.borderColor}`,
    ...trim
  })
}

const parseProps = ({
  className,
  type,
  showTrim,
  ...props
}) => ({
  className: cx(`${getStyle({ type, showTrim })}`, className),
  ...props
})

const AlertIcon = ({ type, ...props }) => {
  switch (type) {
    case 'success': return <SuccessAlertIcon {...props} />
    case 'question': return <QuestionAlertIcon {...props} />
    case 'warning': return <WarningAlertIcon {...props} />
    case 'danger': return <DangerAlertIcon {...props} />
    default: return null
  }
}

AlertIcon.propTypes = {
  ...SuccessAlertIcon.propTypes
}

AlertIcon.defaultProps = {
  marginTop: minorScale(1),
  marginRight: majorScale(2)
}

const Alert = ({ children, showIcon, ...props }) => {
  return (
    <Pane {...parseProps(props)}>
      {showIcon && <AlertIcon flexShrink='0' type={props.type} />}
      <Pane>
        {children}
      </Pane>
    </Pane>
  )
}

Alert.propTypes = {
  ...Pane.propTypes,
  type: PropTypes.oneOf([
    'naked',
    'success',
    'warning',
    'danger',
    'question'
  ]),
  showIcon: PropTypes.bool,
  showTrim: PropTypes.bool
}

Alert.defaultProps = {
  showIcon: true,
  showTrim: true,
  type: 'naked',
  white: true,
  rounded: true,
  paddingX: majorScale(3),
  paddingY: majorScale(2),
  textStyle: 'body1',
  display: 'flex',
  width: '440px',
  position: 'relative',
  overflow: 'hidden'
}

Alert.displayName = 'Alert'

export default Alert
