import React from 'react'
import PropTypes from 'prop-types'
import Box from './Box'
import theme from './theme'
const { majorScale } = theme
const { minorScale } = theme

const IconSize = {
  mini: minorScale(3),
  small: majorScale(2),
  big: majorScale(3)
}

const Icon = ({ size, ...props }) => {
  const realSize = IconSize.hasOwnProperty(size) ? IconSize[size] : size

  return (
    <Box is='span' width={realSize} height={realSize} {...props} />
  )
}

Icon.propTypes = {
  size: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.oneOf(Object.keys(IconSize))
  ]),
  fill: PropTypes.string
}

Icon.defaultProps = {
  size: 'mini',
  fill: 'currentColor',
  display: 'inline-block'
}

export default Icon
