import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import theme from './theme'
import Box from './Box'
import Color from 'color'

const transparentBg = Color(theme.rawColors.grey400).alpha(0).rgb().string()
const opaqueBg = Color(theme.rawColors.grey400).alpha(0.8).rgb().string()

const fadeInAnimation = css.keyframes('fadeInAnimation', {
  from: {
    backgroundColor: transparentBg
  },
  to: {
    backgroundColor: opaqueBg
  }
})

const fadeOutAnimation = css.keyframes('fadeOutAnimation', {
  from: {
    backgroundColor: opaqueBg
  },
  to: {
    backgroundColor: transparentBg
  }
})

const mainCss = css({
  position: 'fixed',
  zIndex: 10,
  top: 0,
  right: 0,
  bottom: 0,
  left: 0,
  background: opaqueBg,
  animationDuration: theme.animationDuration.slow,
  animationTimingFunction: theme.animationEasing.standard,
  animationFillMode: 'forwards'
})

const parseProps = ({
  className,
  fadeOut,
  onClick,
  onFadeEnd,
  ...props
}) => props

class Overlay extends Component {
  constructor () {
    super()
    this.handleClick = this.handleClick.bind(this)
    this.handleAnimationEnd = this.handleAnimationEnd.bind(this)
  }

  componentDidMount () {
    document.body.style.overflow = 'hidden'
  }

  componentWillUnmount () {
    document.body.style.overflow = 'initial'
  }

  render () {
    const { fadeOut, children } = this.props
    const style = {
      animationName: `${fadeOut ? fadeOutAnimation : fadeInAnimation}`
    }

    return (
      <Box
        {...parseProps(this.props)}
        className={`${mainCss}`}
        style={style}
        onRef={(node) => (this.node = node)}
        onClick={this.handleClick}
        onAnimationEnd={this.handleAnimationEnd}
      >
        {children}
      </Box>
    )
  }

  handleClick (e) {
    if (this.props.onClick && e.target === this.node) {
      this.props.onClick()
    }
  }

  handleAnimationEnd (e) {
    if (this.props.onFadeEnd && e.target === this.node) {
      this.props.onFadeEnd()
    }
  }
}

Overlay.propTypes = {
  ...Box.propTypes,
  fadeOut: PropTypes.bool,
  onClick: PropTypes.func,
  onFadeEnd: PropTypes.func
}

Overlay.defaultProps = {
  fadeOut: false
}

Overlay.displayName = 'Overlay'

export default Overlay
