import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import Box from './Box'
import { Body1 } from './TextStyles'
import theme from './theme'
const { minorScale, majorScale } = theme
import splitProps from './utils/splitProps'

const labelStyles = css({
  cursor: 'pointer'
})

const inputStyles = css({
  left: 0,
  opacity: 0,
  position: 'absolute',
  top: 0,
  zIndex: -1,
  '&:disabled + span': {
    backgroundColor: theme.colors.borderColor
  },
  '&:checked + span::before': {
    content: '""',
    position: 'absolute',
    height: '6px',
    width: '6px',
    top: '50%',
    left: '50%',
    transform: 'translate(-50%, -50%)',
    borderRadius: '50%',
    display: 'block',
    backgroundColor: theme.colors.activeColor
  }
})

const controlStyles = css({
  position: 'relative',
  top: '3px',
  height: majorScale(2),
  width: majorScale(2),
  borderRadius: '50%',
  boxShadow: `inset 0 0 0 1px ${theme.colors.borderColor}`,
  display: 'inline-block',
  marginRight: minorScale(3)
})

const Radio = ({ className, label, children, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(props,
    /margin|width|height|display|position/gi)

  return (
    <Box is='label' {...matchedProps} {...labelStyles}>
      <input type='radio' {...inputStyles} {...unmatchedProps} />
      <span {...controlStyles} />
      <Body1 is='span'>{children}</Body1>
    </Box>
  )
}

Radio.propTypes = {
  children: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  label: PropTypes.string
}

Radio.defaultProps = {
  marginY: majorScale(1),
  position: 'relative',
  display: 'block'
}

Radio.displayName = 'Radio'

export default Radio
