import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import Box from './Box'
import DoubleTriangle from './DoubleTriangle'
import theme from './theme'
import splitProps from './utils/splitProps'
const { minorScale, majorScale, controlStateStyles, controlSizes } = theme

const selectStyles = css({
  '& select': {
    appearance: 'none',
    border: controlStateStyles.default.border,
    backgroundColor: controlStateStyles.default.backgroundColor,
    color: controlStateStyles.default.color,
    cursor: 'pointer',
    transition: controlStateStyles.default.transition
  },
  '& > select:hover': {
    border: controlStateStyles.hover.border,
    color: controlStateStyles.hover.color
  },
  '& > select:focus': {
    outline: 'none',
    border: controlStateStyles.focus.border,
    color: controlStateStyles.focus.color,
    boxShadow: controlStateStyles.focus.boxShadow
  }
})
const SelectWrapperBox = props => <Box className={`${selectStyles}`} {...props} />
SelectWrapperBox.displayName = 'SelectWrapperBox'

const iconStyles = css({
  position: 'absolute',
  transform: 'translateY(-50%)',
  pointerEvents: 'none',
  top: '50%'
})
const SelectIcon = props => <DoubleTriangle className={`${iconStyles}`} {...props} />
SelectIcon.displayName = 'SelectIcon'

const renderOptions = (options = []) => {
  return options
    .map(item => typeof item === 'object' ? item : ({ value: item, label: item }))
    .map((item, i) => (
      <option key={`option__${item.value}__${i}`} value={item.value}>
        {item.label}
      </option>
    ))
}

function useControlSizes ({ size, ...props }) {
  const sizes = controlSizes[size]

  return {
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'small' ? minorScale(3) : majorScale(2),
    ...props
  }
}

const Select = ({ options, children, ...props }) => {
  const { matchedProps, unmatchedProps } = splitProps(useControlSizes(props),
    /margin|width|height|display/gi)

  return (
    <SelectWrapperBox position='relative' display='flex' {...matchedProps}>
      <SelectIcon right={props.size === 'small' ? majorScale(1) : minorScale(3)} />
      <Box flex='1' {...unmatchedProps}>{options ? renderOptions(options) : children}</Box>
    </SelectWrapperBox>
  )
}

Select.propTypes = {
  options: PropTypes.oneOfType([
    PropTypes.arrayOf(PropTypes.string),
    PropTypes.arrayOf(PropTypes.shape({
      value: PropTypes.string,
      label: PropTypes.string
    }))
  ]),
  size: PropTypes.oneOf(Object.keys(controlSizes))
}

Select.defaultProps = {
  is: 'select',
  rounded: true,
  size: 'default'
}

Select.displayName = 'Select'

export default Select
