import React from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import objectValues from 'object-values'

const SpaceType = {
  VERTICAL: 'vertical',
  HORIZONTAL: 'horizontal'
}

const parseSpaceProps = ({
  step,
  type = SpaceType.VERTICAL, /* backwards compatible */
  value = 0,
  x,
  y,
  className,
  ...props
}) => {
  const style = {}

  if (x || type === SpaceType.HORIZONTAL) {
    style.display = 'inline-block'
    style.width = x
  } else if (y || type === SpaceType.VERTICAL) {
    style.display = 'block'
    style.height = y
  }

  return { className: cx('Space', className), style, ...props }
}

const Space = ({
  is = 'div',
  ...props
}) => React.createElement(is, parseSpaceProps(props))

Space.propTypes = {
  type: PropTypes.oneOf(objectValues(SpaceType)),
  is: PropTypes.string,
  x: PropTypes.number,
  y: PropTypes.number,
  value: PropTypes.number /* px value */
}

Space.displayName = 'Space'

export {
  Space,
  SpaceType
}
