import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Box from './Box'
import theme from './theme'
const { minorScale, majorScale } = theme

const SubNavigationBarLink = props => <Link {...css({
  '&:active, &:hover, &.active': {
    boxShadow: `0 1px ${theme.rawColors.blue500}`
  }
})} {...props} />

SubNavigationBarLink.defaultProps = {
  secondary: true,
  textStyle: 'body1',
  paddingBottom: majorScale(2),
  marginX: minorScale(3)
}

const SubNavigationBarTitle = props => <Text {...props} />

SubNavigationBarTitle.defaultProps = {
  is: 'h2',
  textStyle: 'display4'
}

const SubNavigationBarPane = props => <Pane {...props} />

SubNavigationBarPane.defaultProps = {
  display: 'flex',
  white: true,
  borderBottom: true
}

const SubNavigationBar = ({ left, right, children }) => {
  let leftChild
  if (typeof left === 'string') {
    leftChild = <SubNavigationBarTitle>{left}</SubNavigationBarTitle>
  } else {
    leftChild = left
  }

  return (
    <SubNavigationBarPane>
      <Pane width='25%' padding={majorScale(2)} flex='0 0 auto'>{leftChild}</Pane>
      <Pane flexAuto textAlign='center' display='flex' alignItems='flex-end' justifyContent='center'>{children}</Pane>
      <Pane width='25%' textAlign='right' flex='0 0 auto'>{right}</Pane>
    </SubNavigationBarPane>
  )
}

SubNavigationBar.propTypes = {
  ...Box.propTypes,
  left: PropTypes.oneOfType([
    PropTypes.node,
    PropTypes.string
  ]),
  right: PropTypes.node
}

SubNavigationBar.defaultProps = {
  theme
}

export {
  SubNavigationBar,
  SubNavigationBarTitle,
  SubNavigationBarLink
}
