import React from 'react'
import PropTypes from 'prop-types'
import Markdown from 'react-remarkable'
import { css } from 'glamor'
import { theme, Box } from '../components'
const { majorScale } = theme

const contentStyles = {
  fontFamily: theme.fonts.sans,
  fontSize: theme.textStyles.body1.fontSize,
  fontWeight: theme.textStyles.body1.fontWeight,
  letterSpacing: theme.textStyles.body1.letterSpacing,
  '& > *': {
    margin: 0,
    padding: 0,
    border: 0,
    fontSize: '100%',
    font: 'inherit',
    verticalAlign: 'baseline'
  },
  '& ol, & ul': {
    listStyle: 'none'
  },
  '& blockquote, & q': {
    margin: 0,
    paddingLeft: majorScale(2),
    borderLeft: `2px solid ${theme.backgrounds.white.borderColor}`,
    fontStyle: 'italic',
    quotes: 'none'
  },
  '& h1': {
    ...theme.textStyles.display1,
    color: theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& h2': {
    ...theme.textStyles.display2,
    color: theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& h3': {
    ...theme.textStyles.display3,
    color: theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& h4, & h5, & h6': {
    ...theme.textStyles.display4,
    color: theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  },
  '& p, & ul, & ol': {
    ...theme.textStyles.body1,
    maxWidth: '40em',
    margin: '1em 0'
  },
  '& ul': {
    listStyle: 'disc',
    listStylePosition: 'outside',
    marginLeft: '1.2em',
    padding: 0
  },
  '& ol': {
    listStyle: 'decimal'
  },
  '& em': {
    fontStyle: 'italic'
  },
  '& strong': {
    fontWeight: 500
  },
  '& p > code, & li > code, & table code': {
    ...theme.textStyles.body1,
    fontFamily: theme.fonts.sans,
    display: 'inline-block',
    backgroundColor: theme.backgrounds.tint1.backgroundColor,
    boxShadow: `inset 0 0 0 1px ${theme.colors.borderColor}`,
    padding: '0 0.5em',
    borderRadius: theme.borderRadius[0],

    '&:before, &:after': {
      content: '\\00a0',
      letterSpacing: '-0.2em'
    }
  },
  '& pre': {
    margin: '1em 0',
    overflowX: 'auto',
    textAlign: 'left',
    display: 'block',
    whiteSpace: 'pre',
    backgroundColor: theme.backgrounds.tint1.backgroundColor,
    boxShadow: `inset 0 0 0 1px ${theme.colors.borderColor}`,
    padding: theme.minorScale(3),
    borderRadius: theme.borderRadius[0]
  },
  '& pre code': {
    ...theme.textStyles.mono,
    fontFamily: theme.fonts.mono,
    padding: 0,
    background: 'none',
    '&:before, &:after': {
      content: 'none',
      letterSpacing: 0
    }
  },
  '& hr': {
    background: theme.backgrounds.tint1.backgroundColor,
    border: 0,
    height: '1px',
    margin: '32px 0'
  },
  '& table': {
    borderCollapse: 'collapse',
    borderSpacing: 0,
    width: '100%',
    margin: '1em 0'
  },
  '& thead': {
    borderBottom: `1px solid ${theme.colors.borderColor}`,
    backgroundColor: theme.backgrounds.tint1.backgroundColor,
    position: 'relative',
    textAlign: 'left',
    padding: '0 20px',
    boxSizing: 'content-box'
  },
  '& th': {
    fontWeight: '500'
  },
  '& tbody tr': {
    borderBottom: `1px solid ${theme.colors.borderColor}`,
    background: theme.colors.white
  },
  '& td, & th': {
    padding: '0.8em'
  }
}

const parseProps = ({ children, ...props }) => {
  if (typeof children === 'string') {
    return { children: <Markdown source={children} />, ...props }
  }
  return { children, ...props }
}

const Content = ({ markdown, ...props }) =>
  <Box {...css(contentStyles)} {...parseProps(props)} />

Content.propTypes = {
  markdown: PropTypes.bool
}

Content.displayName = 'Content'

export default Content
