import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Avatar,
  Box,
  Triangle,
  theme
} from '../components'
import Content from './Content'
const { minorScale, majorScale } = theme

const imageURL = 'http://www.casinomeister.com/forums/avatars/jufo.gif?dateline=1345999507'

export default function avatarStory (module) {
  storiesOf('Avatar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Avatar

The Avatar component allows easy avatar composition. Implements \`<Box />\`.

* Falls back to initials on error
* Adds a title attribute with the name

\`\`\`
const imageURL = '${imageURL}'

<Avatar src={imageURL}>Segment Sloth</Avatar>
<Avatar nameShown src='http://www.example.com/BAD_URL'>Segment Sloth</Avatar>
\`\`\`

`}
          </Content>
          <Avatar marginRight={minorScale(2)} src={imageURL}>Segment Sloth</Avatar>
          <Avatar nameShown src='http://www.example.com/BAD_URL'>Segment Sloth</Avatar>
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`children\`| string | undefined | the name of the avatar/person displayed
\`imageSize\`| string / small, default | 40px | the width and height of the image
\`nameShown\`| boolean | false | wether to show a name under the Avatar
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with circle only', () => (
      <App>
        <Pane white padding={majorScale(3)} clearfix>
          <Avatar marginLeft={majorScale(1)} marginRight={majorScale(1)} src={imageURL}>Segment Sloth</Avatar>
          <Avatar marginLeft={majorScale(1)} marginRight={majorScale(1)} src='http://www.example.com/badurl'>Segment Sloth</Avatar>
        </Pane>
      </App>
    ))
    .add('with name shown', () => (
      <App>
        <Pane white padding={majorScale(3)} clearfix>
          <Avatar nameShown marginLeft={majorScale(1)} marginRight={majorScale(1)} src={imageURL}>Segment Sloth</Avatar>
          <Avatar nameShown marginLeft={majorScale(1)} marginRight={majorScale(1)} src='http://www.example.com/badurl'>Segment Sloth</Avatar>
        </Pane>
      </App>
    ))
    .add('with Triangle', () => (
      <App>
        <Pane white padding={majorScale(3)} clearfix>
          <Box display='flex' alignItems='center'>
            <Avatar marginLeft={majorScale(1)} marginRight={majorScale(1)} src={imageURL}>Segment Sloth</Avatar>
            <Triangle aim='down' display='inline-flex' />
          </Box>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Avatar marginLeft={majorScale(1)} marginRight={majorScale(1)} src={imageURL}>Segment Sloth</Avatar>
    ))
}
