import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  BottomSheet,
  Pane,
  Button,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

class BottomSheetTrigger extends React.Component {
  constructor () {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle () {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render () {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open BottomSheet</Button>
        <BottomSheet
          title='Sheet Title'
          side={this.props.side} isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding={majorScale(2)} height='800px'>Hello World</Pane>
        </BottomSheet>
      </Pane>
    )
  }
}

export default function BottomSheetStory (module) {
  storiesOf('Bottom Sheet', module)
    .add('usage', () => (
      <App white>
        <Pane padding={majorScale(10)}>
          <Content markdown>
            {`
# Bottom Sheet

The BottomSheet component. Implement the \`<Pane />\` component.\

* TODO: padding top is hardcoded to 62px for content

\`\`\`
class BottomSheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open BottomSheet</Button>
        <BottomSheet
          title='Sheet Title'
          side={this.props.side} isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding={majorScale(2)} height='800px'>Hello World</Pane>
        </BottomSheet>
      </Pane>
    )
  }
}

<BottomSheetTrigger />
\`\`\`

`}
          </Content>
          <BottomSheetTrigger />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`isOpen\` | boolean | undefined | is the BottomSheet open
\`onClose\` | function | undefined | onClose handler to manage state
\`title\` | string/node | undefined | gets title styling when string
\`navigationBarLeft\` | node | \`<BottomSheetCloseButton />\` | gets a close handler on the fly
\`navigationBarRight\` | node | undefined | right of navigation bar
`}
          </Content>
        </Pane>
      </App>
    )).add('plain', () => (
      <App padding={majorScale(2)}>
        <BottomSheetTrigger />
      </App>
    ))
    .add('standalone', () => (
      <BottomSheetTrigger />
    ))
}
