import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Triangle,
  DoubleTriangle,
  Arrow,
  Chevron,
  Close,
  ExclamationCircle,
  CheckCircle,
  SearchIcon,
  HelpIcon,
  CogIcon,
  SuccessAlertIcon,
  QuestionAlertIcon,
  DangerAlertIcon,
  WarningAlertIcon,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

const Docs = () => <Content markdown>
  {`
prop | type | default | description
-----|------| --------|-------------
\`aim\`| up/top, right, down/bottom, left | right | the direction the icon is aiming
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
`}
</Content>

export default function iconsStory (module) {
  storiesOf('Icons', module)
    .add('Triangle', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Triangle

The Triangle icon is a multi purpose directional icon. Implements \`<Box />\`.

\`\`\`
<Triangle aim='up' />
<Triangle aim='right' />
<Triangle aim='down' />
<Triangle aim='left' />
<Triangle aim='right' transform='translateY(-50%)' />
\`\`\`

`}
          </Content>
          <Triangle aim='up' />
          <Triangle aim='right' />
          <Triangle aim='down' />
          <Triangle aim='left' />
          <Triangle aim='right' transform='translateY(-50%)' />
          <Docs />
        </Pane>
      </App>
    ))
    .add('Arrow', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Arrow

The Arrow icon is a multi purpose directional icon. Implements \`<Box />\`.

\`\`\`
<Arrow aim='up' />
<Arrow aim='right' />
<Arrow aim='down' />
<Arrow aim='left' />
\`\`\`

`}
          </Content>
          <Arrow aim='up' />
          <Arrow aim='right' />
          <Arrow aim='down' />
          <Arrow aim='left' />
          <Docs />
        </Pane>
      </App>
    ))
    .add('Chevron', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Chevron

The Chevron icon is a multi purpose directional icon. Implements \`<Box />\`.

\`\`\`
<Chevron aim='up' />
<Chevron aim='right' />
<Chevron aim='down' />
<Chevron aim='left' />
\`\`\`

`}
          </Content>
          <Chevron aim='up' />
          <Chevron aim='right' />
          <Chevron aim='down' />
          <Chevron aim='left' />
          <Docs />
        </Pane>
      </App>
    ))
    .add('Close', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Close

The Close icon is a base for close buttons. Implements \`<Box />\`.

\`\`\`
<Close />
\`\`\`

`}
          </Content>
          <Close />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Double Triangle', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Double Triangle

The DoubleTriangle icon is a icon for select's. Implements \`<Box />\`.

\`\`\`
<DoubleTriangle />
\`\`\`

`}
          </Content>
          <DoubleTriangle />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Exclamation Circle', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Exclamation Circle

The ExclamationCircle icon is a icon for input warnings. Implements \`<Box />\`.

\`\`\`
<ExclamationCircle />
\`\`\`

`}
          </Content>
          <ExclamationCircle />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | dark text color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Check Circle', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Check Circle

The CheckCircle icon is an icon for check marks in the UI. Implements \`<Box />\`.

\`\`\`
<CheckCircle />
\`\`\`

`}
          </Content>
          <CheckCircle />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | primary color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Search Icon', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Search Icon

The SearchIcon icon is an icon for search inputs in the UI. Implements \`<Box />\`.

\`\`\`
<SearchIcon />
\`\`\`

`}
          </Content>
          <SearchIcon />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | mini | the size of the icon
\`fill\` | string | primary color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Help Icon', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Help Icon

The Help icon is often used as a trigger for tooltips. Implements \`<Box />\`.

\`\`\`
<HelpIcon />
\`\`\`

`}
          </Content>
          <HelpIcon />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | small | the size of the icon
\`fill\` | string | primary color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Cog Icon', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Cog Icon

The Cog icon is often used settings. Implements \`<Box />\`.

\`\`\`
<CogIcon />
\`\`\`

`}
          </Content>
          <CogIcon />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | small | the size of the icon
\`fill\` | string | primary color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Success Alert Icon', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Success Alert Icon

The Success Alert Icon is used in the \`<Alert type='success' />\` component.

Implements \`<Box />\`.

\`\`\`
<SuccessAlertIcon />
\`\`\`

`}
          </Content>
          <SuccessAlertIcon />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | small | the size of the icon
\`fill\` | string | success color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Question Alert Icon', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Question Alert Icon

The Question Alert Icon is used in the \`<Alert type='question' />\` component.

Implements \`<Box />\`.

\`\`\`
<QuestionAlertIcon />
\`\`\`

`}
          </Content>
          <QuestionAlertIcon />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | small | the size of the icon
\`fill\` | string | question color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Warning Alert Icon', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Warning Alert Icon

The Warning Alert Icon is used in the \`<Alert type='warning' />\` component.

Implements \`<Box />\`.

\`\`\`
<WarningAlertIcon />
\`\`\`

`}
          </Content>
          <WarningAlertIcon />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | small | the size of the icon
\`fill\` | string | warning color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
    .add('Danger Alert Icon', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Danger Alert Icon

The Danger Alert Icon is used in the \`<Alert type='danger' />\` component.

Implements \`<Box />\`.

\`\`\`
<DangerAlertIcon />
\`\`\`

`}
          </Content>
          <DangerAlertIcon />
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`size\` | mini, small, big | small | the size of the icon
\`fill\` | string | danger color | the fill of the icon
          `}
          </Content>
        </Pane>
      </App>
    ))
}
