import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Text,
  NavigationBar,
  NavigationBarLink,
  SubNavigationBar,
  SubNavigationBarLink,
  Sidebar,
  SidebarLink,
  Avatar,
  Box,
  Link,
  Triangle,
  Input,
  Button,
  theme
} from '../components'
const { majorScale } = theme

const Label = (props) => <Text is='label' textStyle='display4' bold display='block' {...props} />

const AvatarWithTriangle = () =>
  <Box display='inline-flex' alignItems='center'>
    <Avatar marginLeft={majorScale(1)} marginRight={majorScale(1)} src='' imageSize='small'>Segment Sloth</Avatar>
    <Triangle aim='down' display='inline-flex' fill='white' />
  </Box>

export default function layoutsStory (module) {
  storiesOf('Layouts', module)
    .add('tabbed Nav + Sub Nav', () => (
      <App>
        <NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>
          <NavigationBarLink active>Sources</NavigationBarLink>
          <NavigationBarLink href='#'>Warehouses</NavigationBarLink>
        </NavigationBar>
        <SubNavigationBar left={'Sources'}>
          {['Overview', 'Integrations', 'Debugger', 'Schema', 'Settings'].map(name =>
            <SubNavigationBarLink key={name} href='#' active={name === 'Settings'}>
              {name}
            </SubNavigationBarLink>
          )}
        </SubNavigationBar>
        <Pane flexAuto display='flex'>
          <Sidebar>
            <SidebarLink key='Basic' href='#' active>Basic</SidebarLink>
            <SidebarLink key='Collaborators' href='#'>Collaborators</SidebarLink>
            <SidebarLink key='Settings' href='#'>SQL Settings</SidebarLink>
            <SidebarLink key='Schema' href='#'>Clear Schema</SidebarLink>
            <SidebarLink key='Workspace' href='#'>Transfer To Workspace</SidebarLink>
            <SidebarLink key='Keys' href='#'>API Keys</SidebarLink>
          </Sidebar>
          <Pane display='flex' flexAuto justifyContent='center'>
            <Pane width='680px' margin={majorScale(6)}>
              <Pane white rounded border padding={majorScale(6)}>
                <Text is='h2' textStyle='display2' marginBottom={majorScale(4)}>Basic Settings</Text>
                <Label htmlFor='Nickname'>Nickname</Label>
                <Input readOnly id='Nickname' value='Slothzilla' name='Nickname' marginTop={majorScale(1)} marginBottom={majorScale(1)} />
                <Text textStyle='body2'>Pick a name to help you identify this source in Segment.</Text>
                <Button primary marginTop={majorScale(4)}>Save changes</Button>
                <Pane white borderTop textStyle='body2' marginTop={majorScale(4)} paddingTop={majorScale(4)}>
                  <Link underline primary href=''>Delete this source.</Link> No data will be deleted from your source.
                </Pane>
              </Pane>
            </Pane>
          </Pane>
        </Pane>
      </App>
    ))
}
