import React from 'react'
import { storiesOf } from '@kadira/storybook'
import Color from 'color'
import {
  App,
  Pane,
  Display1,
  Display3,
  Text,
  Code,
  Body1,
  Body2,
  Popover,
  theme
} from '../components'
const { majorScale } = theme
const mjs = majorScale

const pickColor = (color) => {
  return Object.keys(theme.rawColors)
    .filter(key => key.indexOf(color) > -1)
    .map(key => ({
      key,
      val: theme.rawColors[key]
    }))
}

const groupedColors = {
  green: pickColor('green'),
  blue: pickColor('blue'),
  grey: pickColor('grey'),
  pink: pickColor('pink'),
  peach: pickColor('peach')
}

const ColorSwatchDetails = ({ color }) =>
  <Pane width='160px' height='160px' padding={mjs(2)}>
    <Body1>{Color(color).hsl().round().string()}</Body1>
    <Body1>{Color(color).rgb().round().string()}</Body1>
    <Body1>Hue: {Color(color).hsl().round().hue()}</Body1>
  </Pane>

function findRawColor (color) {
  return Object.keys(theme.rawColors).find(key => theme.rawColors[key] === color)
}

const ColorSwatch = ({ name, color, showRaw }) =>
  <Pane style={{ float: 'left' }} marginRight={mjs(2)} marginBottom={mjs(2)} textAlign='center'>
    <Popover useArrow content={<ColorSwatchDetails color={color} />}>
      <Pane display='inline-block' circle width='64px' height='64px' style={{ backgroundColor: color }} />
    </Popover>
    <Body1>{name}</Body1>
    <Body2>{showRaw && findRawColor(color)}</Body2>
    <Body2 textColor='muted'>{color}</Body2>
  </Pane>

const Colors = ({ colors, title, hue }) =>
  <Pane clearfix marginBottom={mjs(4)}>
    <Display3 marginY={mjs(2)}>{title} <Text is='span' textColor='muted'>&middot; hue: {hue}</Text></Display3>
    <Pane>
      {colors.map(obj => <ColorSwatch key={obj.key} name={obj.key} color={obj.val} />)}
    </Pane>
  </Pane>

const TextColors = () =>
  <Pane marginBottom={majorScale(8)} clearfix>
    <Display1>Text Colors</Display1>
    <Body1>The following colors are available as text colors. Accessible on <Code>theme.textColors[color]</Code>.</Body1>
    <Pane marginTop={mjs(3)} clearfix>
      {Object.keys(theme.textColors).map(key => <ColorSwatch name={key} color={theme.textColors[key]} showRaw />)}
    </Pane>
  </Pane>

const FunctionalColors = () =>
  <Pane marginBottom={majorScale(8)} clearfix>
    <Display1>Functional Colors</Display1>
    <Body1>You should try to use functional colors instead of raw colors. Accessible on <Code>theme.colors[color]</Code>.</Body1>
    <Pane marginTop={mjs(3)} clearfix>
      {Object.keys(theme.colors).map(key => <ColorSwatch key={key} name={key} color={theme.colors[key]} showRaw />)}
    </Pane>
  </Pane>

const RawColors = () =>
  <Pane marginBottom={majorScale(8)} clearfix>
    <Display1>Raw Colors</Display1>
    <Body1>These are the underlying colors that support the functional colors. Accessible on <Code>theme.rawColors[color]</Code>.</Body1>
    <Colors colors={groupedColors.green} title='Green' hue='151' />
    <Colors colors={groupedColors.blue} title='Blue' hue='209' />
    <Colors colors={groupedColors.grey} title='Grey' hue='209' />
    <Colors colors={groupedColors.pink} title='Pink' hue='329' />
    <Colors colors={groupedColors.peach} title='Peach' hue='27' />
  </Pane>

export default function themeStory (module) {
  storiesOf('Design / Theme', module)
    .add('colors', () => (
      <App>
        <Pane flexAuto white padding={majorScale(10)} clearfix>
          <FunctionalColors />
          <TextColors />
          <RawColors />
        </Pane>
      </App>
    ))
}
